@@ -1,16 +1,18 @@
 #ifndef XBMC_H
 #define XBMC_H
 
-#include <QString>
-#include <QNetworkAccessManager>
+#include "xbmcclient.h"
 
-class Xbmc : public QObject
+#include <QString>
+
+class Xbmc
 {
-    Q_OBJECT
 public:
-    Xbmc(QObject* parent = 0);
+    Xbmc();
     ~Xbmc();
 
+    void setup();
+
     void actionRight();
     void actionLeft();
     void actionUp();
@@ -32,16 +34,9 @@ public:
     void actionSendKeyEsc();
     void actionContextMenu();
 
-private slots:
-    void commandFinished();
-
 private:
-    void do_command1(const QString& command, int id);
-
-    void do_command_action(int action);
-    void do_command_send_key(int key);
-
-    QNetworkAccessManager *m_manager;
+    int m_socket;
+    CAddress *m_address;
 };
 
 #endif // XBMC_H
